import { Level } from "../models/data/level.model";

export interface Column {
    key: string;
    name: string;
}

export class ComponentWithTable {
    private _hiddenColumns: Column[] = [];
    set hiddenColumns(value: Column[]) {
        this._hiddenColumns = value;
        localStorage.setItem("hiddenColumns", JSON.stringify(value));
    }

    get hiddenColumns(): Column[] {
        return this._hiddenColumns;
    }

    public name: string = "";
    public columns: Column[] = [];

    constructor(
        name: string,
        columns: string[]
    ) {
        this.name = name;
        this.columns = columns.map(column => {
            return { key: this.getKey(column), name: column };
        });
        let hiddenColumns = localStorage.getItem("hiddenColumns");
        if (!hiddenColumns) {
            localStorage.setItem("hiddenColumns", JSON.stringify([{}]));
            hiddenColumns = localStorage.getItem("hiddenColumns") ?? JSON.stringify([{}]);
        }
        this._hiddenColumns = JSON.parse(hiddenColumns);
    }

    private getKey(column: string): string {
        return `${this.name}_${column}`;
    }

    public isColumnVisible(column: string): boolean {
        return !this._hiddenColumns.map(column => column.key).includes(this.getKey(column));
    }

    public callback = (data: any[]) => {
        this.save(data);
    };

    public onRowEditSave(newLevel: any, index: number) {
    }

    public save(data: any[]) {
        for (let i = 0; i < data.length; i++) {
            this.onRowEditSave(data[i], i);
        }
    }
}
