import { Component, EventEmitter, Input, Output, ViewChild } from "@angular/core";
import { ToastService } from "../../../../services/toast/toast.service";
import { TranslateService } from "@ngx-translate/core";

interface UploadEvent {
    originalEvent: Event;
    files: File[];
}

@Component({
    selector: "app-data-import-and-export",
    templateUrl: "./data-import-and-export.component.html",
    styleUrls: ["./data-import-and-export.component.scss"]
})
export class DataImportAndExportComponent {

    @ViewChild("upload") upload: any;

    private _data: any[] = [];

    @Input() name: string = "";

    @Input()
    set data(data: any[]) {
        this._data = data;
        this.dataChange.emit(data);
    }

    get data(): any[] {
        return this._data;
    }

    @Output() dataChange: EventEmitter<any[]> = new EventEmitter<any[]>();
    @Input() callback!: (data: any[]) => void;

    public constructor(
        private toastService: ToastService,
        private translate: TranslateService
    ) {

    }

    public export() {
        const json = JSON.stringify(this.data);
        const element = document.createElement("a");
        element.setAttribute("href", "data:application/json;charset=UTF-8," + encodeURIComponent(json));
        element.setAttribute("download", `${this.name}.json`);
        element.style.display = "none";
        document.body.appendChild(element);
        element.click(); // simulate click
        document.body.removeChild(element);
    }

    public import(event: { files: File[] }) {
        const file = event.files[0];
        const fileReader = new FileReader();
        fileReader.onload = () => {
            if (!fileReader.result) return;
            this.data = JSON.parse(fileReader.result.toString());
            this.upload.clear();
            this.callback(this.data);
            this.toastService.success(this.translate.instant("common.file.uploaded"), this.translate.instant("common.file.uploaded"));
        };
        fileReader.readAsText(file, "UTF-8");
    }
}
